@@ -255,7 +255,7 @@ class DADSignalInfo(object):
 
 class HPLCSampleInfo(object):
     def __init__(self,
-                 sample_name: str,
+                 sample_file_name: str,
                  datetimestamp: Union[str, datetime.datetime],
                  method_name: str,
                  signals: Union[List[DADSignalInfo], List[str]],
@@ -263,12 +263,12 @@ class HPLCSampleInfo(object):
         """
         Data class for describing an HPLC sample.
 
-        :param sample_name: name for sample
+        :param sample_file_name: name for sample
         :param datetimestamp: date and time stamp for when the sample was run
         :param method_name: name of method used to run the sample
         :param signals: list of signals associated with the run
         """
-        self.sample_name = sample_name
+        self.sample_file_name = sample_file_name
         if type(datetimestamp) is str:
             datetimestamp = datetime.datetime.strptime(
                 _agilent_dt_re.match(datetimestamp).group('dt'),
@@ -289,11 +289,11 @@ class HPLCSampleInfo(object):
 
     def __str__(self):
         return (
-            f'{self.sample_name} run on {self.datetimestamp} with {len(self.signals)} signals'
+            f'{self.sample_file_name} run on {self.datetimestamp} with {len(self.signals)} signals'
         )
 
     def __repr__(self):
-        return f'{self.__class__.__name__}({self.sample_name})'
+        return f'{self.__class__.__name__}({self.sample_file_name})'
 
     @property
     def date(self) -> str:
@@ -308,12 +308,76 @@ class HPLCSampleInfo(object):
     def as_dict(self) -> dict:
         """Returns the sample data as a dictionary"""
         return {
-            'sample_name': self.sample_name,
+            'sample_file_name': self.sample_file_name,
             'datetimestamp': str(self.datetimestamp),
             'method_name': self.method_name,
             'signals': [str(signal) for signal in self.signals]
         }
 
+    @staticmethod
+    def find_acaml(acaml_path: Union[str, pathlib.Path]) -> xml.etree.ElementTree.ElementTree:
+        """
+        Finds an acaml file and loads the element tree
+
+        :param acaml_path: path to acaml file or directory containing acaml file
+        """
+        if isinstance(acaml_path, pathlib.Path) is False:  # type convert to path if raw string
+            acaml_path = pathlib.Path(acaml_path)
+        if acaml_path.is_dir():  # not a acaml file
+            seq_files = [filename for filename in os.listdir(acaml_path) if _seq_acaml_re.match(filename) is not None]
+            samp_files = [filename for filename in os.listdir(acaml_path) if _samp_acaml_re.match(filename) is not None]
+            if len(seq_files) == 1:
+                acaml_path = acaml_path / seq_files[0]
+            elif len(samp_files) == 1:
+                acaml_path = acaml_path / samp_files[0]
+            else:
+                raise IOError(
+                    f'{"Multiple" if len(seq_files) > 1 else "No"}'
+                    f' sequence.acam_ or sample.acaml files were found in the directory "{acaml_path}". '
+                    f'Please refine your search.'
+                )
+        else:
+            if _acaml_re.search(acaml_path.suffix) is None:
+                # todo consider trying to parse anyway
+                raise ValueError(f'The file "{acaml_path}" does not have a valid extension')
+        return xml.etree.ElementTree.parse(acaml_path)
+
+    @classmethod
+    def get_values_from_xml(cls, xml_path: Union[str, pathlib.Path]) -> dict:
+        """
+        Attempts to find a Result.xml file and parse sample information from that. This is an old-style ChemStation
+        metadata file (~B.04.03 era).
+
+        :param xml_path: path to xml or directory containing xml file
+        """
+        if isinstance(xml_path, pathlib.Path) is False:
+            xml_path = pathlib.Path(xml_path)
+        if xml_path.is_dir():
+            try:
+                xml_path = list(xml_path.glob('Result.xml'))[0]
+            except IndexError:
+                raise FileNotFoundError(f'no Result.xml files could be found in the directory {xml_path}')
+        tree = xml.etree.ElementTree.parse(xml_path)
+        root = tree.getroot()
+
+        sample_info = [val for val in root.iter('SampleInformation')][0]
+        sample_name = [val for val in sample_info.iter('SampleName')][0].text
+        method_name = [val for val in sample_info.iter('Method')][0].text
+        dt = datetime.datetime.strptime(
+            [val for val in sample_info.iter('InjectionDateTime')][0].text,
+            '%d-%b-%y, %H:%M:%S',
+        )
+        signals = []
+        for signal in root.iter('Signal'):
+            signals.append(signal.find('Description').text)
+
+        return {
+            'sample_file_name': sample_name,
+            'method_name': method_name,
+            'datetimestamp': dt,
+            'signals': signals,
+        }
+
     @classmethod
     def get_values_from_acaml(cls,
                               acaml: Union[
@@ -330,28 +394,7 @@ class HPLCSampleInfo(object):
         """
         # if provided with a path, create element tree
         if isinstance(acaml, xml.etree.ElementTree.ElementTree) is False:
-            if type(acaml) is str:  # type convert to path if raw string
-                acaml = pathlib.Path(acaml)
-            if os.path.isdir(acaml):  # not a acaml file
-                seq_files = [filename for filename in os.listdir(acaml) if _seq_acaml_re.match(filename) is not None]
-                samp_files = [filename for filename in os.listdir(acaml) if _samp_acaml_re.match(filename) is not None]
-                if len(seq_files) == 1:
-                    acaml = acaml / seq_files[0]
-                elif len(samp_files) == 1:
-                    acaml = acaml / samp_files[0]
-                else:
-                    raise IOError(
-                        f'{"Multiple" if len(seq_files) > 1 else "No"}'
-                        f' sequence.acam_ or sample.acaml files were found in the directory "{acaml}". '
-                        f'Please refine your search.'
-                    )
-            else:
-                if _acaml_re.search(acaml.suffix) is None:
-                    # todo consider trying to parse anyway
-                    raise ValueError(f'The file "{acaml}" does not have a valid extension')
-            acaml = xml.etree.ElementTree.parse(
-                acaml
-            )
+            acaml = cls.find_acaml(acaml)
 
         root = acaml.getroot()
         prefix = _prefix_re.match(root.tag).group('prefix')
@@ -378,12 +421,31 @@ class HPLCSampleInfo(object):
                 pass
 
         return {
-            'sample_name': sample_name,
+            'sample_file_name': sample_name,
             'method_name': method_name,
             'datetimestamp': dt,
             'signals': signals,
         }
 
+    @classmethod
+    def find_and_get_metadata(cls, target_path: Union[str, pathlib.Path]) -> dict:
+        """
+        Attempts to locate and parse metadata files in both old (Result.xml) and new (ACAML) formats.
+        If neither file type can be found, an error will be raised.
+
+        :param target_path: target path to search
+        :return: parsed dictionary for creating HPLCSampleInfo instance
+        """
+        try:
+            return cls.get_values_from_acaml(target_path)
+        except (IOError, ValueError):
+            pass
+        try:
+            return cls.get_values_from_xml(target_path)
+        except FileNotFoundError:
+            pass
+        raise FileNotFoundError(f'a metadata file could not be identified at or in the path {target_path}')
+
     @classmethod
     def create_from_acaml(cls, acaml: Union[str, xml.etree.ElementTree.ElementTree]) -> "HPLCSampleInfo":
         """
@@ -396,6 +458,30 @@ class HPLCSampleInfo(object):
             **cls.get_values_from_acaml(acaml)
         )
 
+    @classmethod
+    def create_from_xml(cls, xml_path: Union[str, xml.etree.ElementTree.ElementTree]) -> "HPLCSampleInfo":
+        """
+        Creates sample structure from a Sample.xml file (old style metadata) in the desired .D folder)
+
+        :param xml_path: path to xml file or parsed element tree root
+        :return: parsed Sample instance
+        """
+        return cls(
+            **cls.get_values_from_xml(xml_path)
+        )
+
+    @classmethod
+    def auto_create(cls, target_path: Union[str, pathlib.Path]) -> "HPLCSampleInfo":
+        """
+        Attempts to automatically create an instance from metadata in the target folder
+
+        :param target_path: path to metadata file or folder containing metadata files
+        :return: HPLCSampleInfo instance
+        """
+        return cls(
+            **cls.find_and_get_metadata(target_path)
+        )
+
 
 class DADSpectrum(AgilentCSDAD2):
     def __init__(self,
@@ -976,7 +1062,7 @@ class DADSignal(DADSignalInfo):
 
 class HPLCSample(HPLCSampleInfo):
     def __init__(self,
-                 sample_name: str,
+                 sample_file_name: str,
                  datetimestamp: Union[str, datetime.datetime],
                  method_name: str,
                  signals: Union[List[DADSignalInfo], List[DADSignal], List[str]],
@@ -987,7 +1073,7 @@ class HPLCSample(HPLCSampleInfo):
         """
         Data class for describing an HPLC sample containing metadata and spectral data.
 
-        :param sample_name: name for sample
+        :param sample_file_name: name for sample
         :param datetimestamp: date and time stamp for when the sample was run
         :param method_name: name of method used to run the sample
         :param signals: list of signals associated with the run
@@ -996,7 +1082,7 @@ class HPLCSample(HPLCSampleInfo):
         """
         HPLCSampleInfo.__init__(
             self,
-            sample_name=sample_name,
+            sample_file_name=sample_file_name,
             datetimestamp=datetimestamp,
             method_name=method_name,
             signals=signals,
@@ -1018,7 +1104,7 @@ class HPLCSample(HPLCSampleInfo):
             file_path = pathlib.Path(file_path)
         if file_path.suffix != '.D' is False or os.path.isdir(file_path) is False:
             raise ValueError(f'The file path "{file_path}" does not appear to be a valid Agilent sample directory')
-        sample_info_values = HPLCSampleInfo.get_values_from_acaml(file_path)
+        sample_info_values = HPLCSampleInfo.find_and_get_metadata(file_path)
         try:
             dad_spectrum = DADSpectrum.create_from_D_file(file_path)
         except FileNotFoundError:
@@ -1040,6 +1126,17 @@ class HPLCSample(HPLCSampleInfo):
         raise NotImplementedError(f'Creation of {cls.__class__.__name__} from acaml is not supported, use '
                                   f'create_from_D_file.')
 
+    @classmethod
+    def create_from_xml(cls, xml_path: Union[str, xml.etree.ElementTree.ElementTree]) -> "HPLCSampleInfo":
+        """
+        Creates sample structure from a Sample.xml file (old style metadata) in the desired .D folder)
+
+        :param xml_path: path to xml file or parsed element tree root
+        :return: parsed Sample instance
+        """
+        raise NotImplementedError(f'Creation of {cls.__class__.__name__} from xml is not supported, use '
+                                  f'create_from_D_file.')
+
     def add_signal(self, new_signal: Union[DADSignalInfo, dict, str]) -> DADSignal:
         """
         Adds a new signal to the HPLCSample instance.
@@ -1112,7 +1209,11 @@ class HPLCSample(HPLCSampleInfo):
         :return: path to the written file
         """
         if output_file is None:
-            output_file = pathlib.Path(self.spectrum.filename).parent / f'{self.spectrum.info["name"]}.xlsx'
+            try:
+                sample_name = self.spectrum.info["name"]
+            except UnicodeDecodeError:
+                sample_name = 'no Sample Name'
+            output_file = pathlib.Path(self.spectrum.filename).parent / f'{sample_name}.xlsx'
         elif isinstance(output_file, pathlib.Path) is False:
             output_file = pathlib.Path(output_file)
 
