@@ -229,6 +229,21 @@ class AcquisitionSearch:
         while self._monitor_thread.is_alive():
             time.sleep(0.01)
 
+    def parent_of_path(self, path: Union[str, pathlib.Path]) -> bool:
+        """
+        Checks whether the provided path is a parent of the instance's path. (The instance's path is a subfolder of
+        the provided path.
+
+        :param path: pathlike
+        :return: provided path is parent
+        """
+        if isinstance(path, pathlib.Path) is False:
+            path = pathlib.Path(path)
+        path = path.absolute()
+        if len(path.parts) < len(self.data_parent.parts):
+            return path.parts == self.data_parent.parts[:len(path.parts)]
+        return False
+
     @classmethod
     def start_monitoring_all_paths(cls):
         """starts the monitor thread on all data paths"""
@@ -264,7 +279,9 @@ class AcquisitionSearch:
             path = pathlib.Path(path)
         if path.is_absolute() is False:
             path = path.absolute()
-        if path in cls.data_paths:
+        if cls.parent_of_any_path(path):
+            raise ValueError(f'the provided path "{path}" is a parent of one or more AcquisitionSearch paths')
+        elif path in cls.data_paths:
             # if path already exists, return
             for inst in cls.instances:
                 if inst.data_parent == path:
@@ -272,6 +289,21 @@ class AcquisitionSearch:
         # otherwise, create a new data monitor
         return cls(path, always_search=always_search, autostart=autostart)
 
+    @classmethod
+    def parent_of_any_path(cls, path: Union[str, pathlib.Path]) -> bool:
+        """
+        Checks whether the provided path is a parent of any path instance.
+
+        :param path: path to check
+        :return: parent of any path
+        """
+        if isinstance(path, pathlib.Path) is False:
+            path = pathlib.Path(path)
+        return any([
+            inst.parent_of_path(path)
+            for inst in cls.instances
+        ])
+
     @classmethod
     def sequence_is_running(cls) -> bool:
         """True if any acquisition search instance is aware of an acquiring flag file"""
